Improve this Doc

# Guide to Angular 1 Documentation

On this page, you will find a list of official Angular resources on various topics.

Just starting out with Angular 1? Try working through our step by step tutorial or try building on our seed project.

- Official Angular 1 Tutorial
- Angular Seed

Ready to find out more about Angular 1?

- What is Angular 1?
- Conceptual Overview

## Core Concepts

### Templates

In Angular applications, you move the job of filling page templates with data from the server to the client. The result is a system better structured for dynamic page updates. Below are the core features you'll use.

- Data binding
- Expressions
- Interpolation
- Directives
- Views and routes (see the example)
- Filters
- HTML compiler
- Forms

### Application Structure

- App wiring: Dependency injection
- Exposing model to templates: Scopes
- Bootstrap: Bootstrapping an app
- Communicating with servers: $http, $resource

### Other Features

- Animation: Core concepts, ngAnimate API
- Security: Security Docs, Strict Contextual Escaping, Content Security Policy, $sanitize, video
- Internationalization and Localization: Angular Guide to i18n and l10n, date filter, currency filter, Creating multilingual support
- Touch events: Touch events
- Accessibility: ngAria

### Testing

- Unit testing: Karma, Unit testing, Testing services,
- End-to-End Testing: Protractor, e2e testing guide

## Community Resources

We have set up a guide to many resources provided by the community, where you can find lots of additional information and material on these topics, a list of complimentary libraries, and much more.

- External Angular 1 resources

## Getting Help

The recipe for getting help on your unique issue is to create an example that could work (even if it doesn't) in a shareable example on Plunker, JSFiddle, or similar site and then post to one of the following:

- Stackoverflow.com
- Angular 1 mailing list
- Angular 1 IRC channel

## Official Communications

Official announcements, news and releases are posted to our blog, G+ and Twitter:

- Angular Blog
- Google+
- Twitter
- Angular on YouTube

## Contributing to Angular 1

Though we have a core group of core contributors at Google, Angular is an open source project with hundreds of contributors. We'd love you to be one of them. When you're ready, please read the Guide for contributing to Angular.

## Something Missing?

Didn't find what you're looking for here? Check out the External Angular 1 resources guide.

If you have awesome Angular 1 resources that belong on that page, please tell us about them on Google+ or Twitter.